==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/modules/user/messages/cs/auth.php <==
<?php

return [
    '<strong>Account</strong> registration' => '<strong>Registrace</strong> účtu',
    '<strong>Change</strong> Password' => '<strong>Změnit</strong> heslo',
    '<strong>Change</strong> your password' => '<strong>Změna</strong> hesla',
    '<strong>Join</strong> the network' => '<strong>Připojit</strong> se k síti.',
    '<strong>Password</strong> changed!' => '<strong>Heslo</strong> bylo změněno!',
    '<strong>Password</strong> recovery' => '<strong>Obnovení</strong> hesla',
    '<strong>Password</strong> recovery!' => '<strong>Obnovení</strong> hesla',
    '<strong>Please</strong> sign in' => '<strong>Přihlášení</strong>',
    '<strong>Registration</strong> successful!' => '<strong>Registrace</strong> byla úspěšná!',
    '<strong>Sign</strong> up' => '<strong>Registrace</strong>',
    '<strong>Your account</strong> has been successfully created!' => '<strong>Váš účet</strong> byl úspěšně vytvořen!',
    'Account' => 'Účet',
    'After activating your account by the administrator, you will receive a notification by email.' => 'Po aktivaci vašeho účtu správcem obdržíte upozornění e-mailem.',
    'Back' => 'Zpět',
    'Change password' => 'Změnit heslo',
    'Confirm' => 'Potvrdit',
    'Create Account' => 'Vytvořit účet',
    'Create account' => 'Vytvořit účet',
    'Don\'t have an account? Join the network by entering your e-mail address.' => 'Nemáte ještě účet? Připojte se k sítí zadáním vaší e-mailové adresy',
    'Due to security reasons you are required to change your password in order to access the platform.' => 'Z bezpečnostních důvodů musíte pro přístup na platformu změnit své heslo.',
    'Enter security code above' => 'Zadejte zabezpečovací kód',
    'Forgot your password?' => 'Zapomněl(a) jste heslo?',
    'Go to login page' => 'Přejít na stránku přihlášení',
    'Group' => 'Skupina',
    'Hello {displayName}' => 'Dobrý den {displayName}',
    'Hello {displayName},' => 'Zdravím {displayName},',
    'If you don\'t use this link within 24 hours, it will expire.' => 'Funkčnost tohoto odkazu vyprší, jestliže na něj do 24 hodin nekliknete.',
    'If you\'re already a member, please login with your username/email and password.' => 'Pokud jste již členem, přihlaste se prosím svým uživatelským jménem/e-mailem a heslem.',
    'Just enter your e-mail address. We\'ll send you recovery instructions!' => 'Stačí zadat vaši e-mailovou adresu, na ni vám zašleme instrukce k obnovení hesla.',
    'Log out' => 'Odhlásit se',
    'Login' => 'Přihlásit se',
    'New user needs approval' => 'Nový uživatel potřebuje schválení',
    'Password' => 'Heslo',
    'Password recovery' => 'Obnovení hesla',
    'Password reset' => 'Změna hesla',
    'Please check your email and follow the instructions!' => 'Prosím zkontrolujte e-mail a následujte instrukce, které vám přišly.',
    'Please click on the link below to view request:' => 'Žádost zobrazíte kliknutím na následující odkaz:',
    'Please enter the letters from the image.' => 'Zadejte prosím písmena z obrázku.',
    'Please login with your username/email and password.' => 'Prosím přihlaste se pomocí svého uživatelského jména / emailu a hesla.',
    'Please use the following link within the next day to reset your password.' => 'Pro obnovu vašeho hesla prosím použijte následující odkaz.',
    'Please wait' => 'Prosím, čekejte',
    'Register' => 'Registrovat',
    'Registration successful' => 'Registrace byla úspěšná!',
    'Remember me' => 'Zapamatovat přihlášení',
    'Reset Password' => 'Obnovit heslo',
    'Reset password' => 'Obnovit heslo',
    'Sign in' => 'Přihlásit se',
    'To log in with your new account, click the button below.' => 'Pro přihlášení do vašeho nového účtu klikněte na tlačítko níže.',
    'User or Password incorrect.' => 'User or Password incorrect.',
    'Username or Email' => 'Uživatelské jméno nebo e-mail',
    'Your email' => 'Vaše e-mailová adresa',
    'Your password' => 'Vaše heslo',
    'Your password has been successfully changed!' => 'Vaše heslo bylo úspěšně změněno!',
    'Your password is incorrect!' => 'Vaše heslo je nesprávné!',
    'a new user {displayName} needs approval.' => 'uživatel {displayName} žádá o přístup.',
    'back to home' => 'Zpět na hlavní stránku',
    'If a user account associated with this email address exists, further instructions will be sent to you by email shortly.' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/user/messages/cs/auth.php <==
<?php

return [
    '<strong>Account</strong> registration' => '<strong>Registrace</strong> účtu',
    '<strong>Change</strong> Password' => '<strong>Změnit</strong> heslo',
    '<strong>Change</strong> your password' => '<strong>Změna</strong> hesla',
    '<strong>Join</strong> the network' => '<strong>Připojit</strong> se k síti.',
    '<strong>Password</strong> changed!' => '<strong>Heslo</strong> bylo změněno!',
    '<strong>Password</strong> recovery' => '<strong>Obnovení</strong> hesla',
    '<strong>Password</strong> recovery!' => '<strong>Obnovení</strong> hesla',
    '<strong>Please</strong> sign in' => '<strong>Přihlášení</strong>',
    '<strong>Registration</strong> successful!' => '<strong>Registrace</strong> byla úspěšná!',
    '<strong>Sign</strong> up' => '<strong>Registrace</strong>',
    '<strong>Your account</strong> has been successfully created!' => '<strong>Váš účet</strong> byl úspěšně vytvořen!',
    'Account' => 'Účet',
    'After activating your account by the administrator, you will receive a notification by email.' => 'Po aktivaci vašeho účtu správcem obdržíte upozornění e-mailem.',
    'Back' => 'Zpět',
    'Change password' => 'Změnit heslo',
    'Confirm' => 'Potvrdit',
    'Create Account' => 'Vytvořit účet',
    'Create account' => 'Vytvořit účet',
    'Don\'t have an account? Join the network by entering your e-mail address.' => 'Nemáte ještě účet? Připojte se k sítí zadáním vaší e-mailové adresy',
    'Due to security reasons you are required to change your password in order to access the platform.' => 'Z bezpečnostních důvodů musíte pro přístup na platformu změnit své heslo.',
    'Forgot your password?' => 'Zapomněl(a) jste heslo?',
    'Go to login page' => 'Přejít na stránku přihlášení',
    'Group' => 'Skupina',
    'Hello {displayName}' => 'Dobrý den {displayName}',
    'Hello {displayName},' => 'Zdravím {displayName},',
    'If you don\'t use this link within 24 hours, it will expire.' => 'Funkčnost tohoto odkazu vyprší, jestliže na něj do 24 hodin nekliknete.',
    'If you\'re already a member, please login with your username/email and password.' => 'Pokud jste již členem, přihlaste se prosím svým uživatelským jménem/e-mailem a heslem.',
    'Just enter your e-mail address. We\'ll send you recovery instructions!' => 'Stačí zadat vaši e-mailovou adresu, na ni vám zašleme instrukce k obnovení hesla.',
    'Log out' => 'Odhlásit se',
    'Login' => 'Přihlásit se',
    'New user needs approval' => 'Nový uživatel potřebuje schválení',
    'Password' => 'Heslo',
    'Password recovery' => 'Obnovení hesla',
    'Password reset' => 'Změna hesla',
    'Please click on the link below to view request:' => 'Žádost zobrazíte kliknutím na následující odkaz:',
    'Please login with your username/email and password.' => 'Prosím přihlaste se pomocí svého uživatelského jména / emailu a hesla.',
    'Please use the following link within the next day to reset your password.' => 'Pro obnovu vašeho hesla prosím použijte následující odkaz.',
    'Please wait' => 'Prosím, čekejte',
    'Register' => 'Registrovat',
    'Remember me' => 'Zapamatovat přihlášení',
    'Reset Password' => 'Obnovit heslo',
    'Reset password' => 'Obnovit heslo',
    'Sign in' => 'Přihlásit se',
    'To log in with your new account, click the button below.' => 'Pro přihlášení do vašeho nového účtu klikněte na tlačítko níže.',
    'User or Password incorrect.' => 'User or Password incorrect.',
    'Username or Email' => 'Uživatelské jméno nebo e-mail',
    'Your email' => 'Vaše e-mailová adresa',
    'Your password' => 'Vaše heslo',
    'Your password has been successfully changed!' => 'Vaše heslo bylo úspěšně změněno!',
    'Your password is incorrect!' => 'Vaše heslo je nesprávné!',
    'a new user {displayName} needs approval.' => 'uživatel {displayName} žádá o přístup.',
    'Almost there!' => '',
    'An email has been sent to {emailAddress}. Please check your inbox to complete the registration.' => '',
    'If a user account associated with this email address exists, further instructions will be sent to you by email shortly.' => '',
    'If you don\'t see the email, please check your spam folder.' => '',
];
